#
# Portions of this file taken from original implementation in altera_avalon_remote_update_cycloneiii_hw.tcl
#

# +-----------------------------------
# | 
# | rsu_cyclone4 "rsu_cyclone4" v1.1
# | Cyclone IV Remote System Update Controller Interface
# | 
# | 
# |    ./rsu_cyclone4.v syn, sim
# |    ./altremote_update_cyclone4.v syn, sim
# | 
# +-----------------------------------

# +-----------------------------------
# | request TCL package from ACDS 11.0
# | 
package require -exact sopc 11.0
# | 
# +-----------------------------------

# +-----------------------------------
# | module rsu_cyclone4
# | 
set_module_property DESCRIPTION "Cyclone IV Remote System Update Controller Interface"
set_module_property NAME rsu_cyclone4
set_module_property VERSION 1.1
set_module_property INTERNAL false
set_module_property OPAQUE_ADDRESS_MAP true
#set_module_property GROUP "Peripherals/FPGA Peripherals"
set_module_property AUTHOR RSF
set_module_property DISPLAY_NAME rsu_cyclone4
set_module_property TOP_LEVEL_HDL_FILE rsu_cyclone4.v
set_module_property TOP_LEVEL_HDL_MODULE rsu_cyclone4
set_module_property INSTANTIATE_IN_SYSTEM_MODULE true
set_module_property EDITABLE false
set_module_property ANALYZE_HDL TRUE
set_module_property STATIC_TOP_LEVEL_MODULE_NAME rsu_cyclone4
set_module_property FIX_110_VIP_PATH false
set_module_property VALIDATION_CALLBACK validate
# | 
# +-----------------------------------

# +-----------------------------------
# | files
# | 
add_file rsu_cyclone4.v {SYNTHESIS SIMULATION}
add_file altremote_update_cyclone4.v {SYNTHESIS SIMULATION}
# | 
# +-----------------------------------

# +-----------------------------------
# | parameters
# | 
# Clock Frequency System Info
add_parameter           clockFrequency      "LONG"          "40000000"
set_parameter_property  clockFrequency      "system_info"   "CLOCK_RATE clock_sink"
set_parameter_property  clockFrequency      "UNITS"         "hertz"
set_parameter_property  clockFrequency      "DISPLAY_NAME"  "Clock Frequency"
# | 
# +-----------------------------------

# +-----------------------------------
# | display items
# | 
# | 
# +-----------------------------------

# +-----------------------------------
# | connection point clock_sink
# | 
add_interface clock_sink clock end
set_interface_property clock_sink clockRate 0

set_interface_property clock_sink ENABLED true

add_interface_port clock_sink clk clk Input 1
# | 
# +-----------------------------------

# +-----------------------------------
# | connection point reset_sink
# | 
add_interface reset_sink reset end
set_interface_property reset_sink associatedClock clock_sink
set_interface_property reset_sink synchronousEdges DEASSERT

set_interface_property reset_sink ENABLED true

add_interface_port reset_sink reset reset Input 1
# | 
# +-----------------------------------

# +-----------------------------------
# | connection point avalon_slave
# | 
add_interface avalon_slave avalon end
set_interface_property avalon_slave addressUnits WORDS
set_interface_property avalon_slave associatedClock clock_sink
set_interface_property avalon_slave associatedReset reset_sink
set_interface_property avalon_slave bitsPerSymbol 8
set_interface_property avalon_slave burstOnBurstBoundariesOnly false
set_interface_property avalon_slave burstcountUnits WORDS
set_interface_property avalon_slave explicitAddressSpan 0
set_interface_property avalon_slave holdTime 0
set_interface_property avalon_slave linewrapBursts false
set_interface_property avalon_slave maximumPendingReadTransactions 0
set_interface_property avalon_slave readLatency 0
set_interface_property avalon_slave readWaitTime 1
set_interface_property avalon_slave setupTime 0
set_interface_property avalon_slave timingUnits Cycles
set_interface_property avalon_slave writeWaitTime 0

set_interface_property avalon_slave ENABLED true

add_interface_port avalon_slave writedata writedata Input 32
add_interface_port avalon_slave readdata readdata Output 32
add_interface_port avalon_slave address address Input 6
add_interface_port avalon_slave chipselect chipselect Input 1
add_interface_port avalon_slave write write Input 1
add_interface_port avalon_slave read read Input 1
add_interface_port avalon_slave waitrequest waitrequest Output 1
# | 
# +-----------------------------------

proc validate {} {
    set freq    [ get_parameter clockFrequency ]
    # clock frequency must be less than 40MHz
    if { [ expr { $freq > 40000000 } ] } {
        send_message error "Clock frequency for Cyclone IV Remote Update Controller can not be greater than 40MHz. Please refer to altremote_update Megafunction User Guide for more detail."
    }
}