-- ***************************************************************************
-- *  Copyright (c) 2017 by Michael Fischer (www.emb4fun.de)
-- *  All rights reserved.
-- *
-- *  Redistribution and use in source and binary forms, with or without 
-- *  modification, are permitted provided that the following conditions 
-- *  are met:
-- *  
-- *  1. Redistributions of source code must retain the above copyright 
-- *     notice, this list of conditions and the following disclaimer.
-- *  2. Redistributions in binary form must reproduce the above copyright
-- *     notice, this list of conditions and the following disclaimer in the 
-- *     documentation and/or other materials provided with the distribution.
-- *  3. Neither the name of the author nor the names of its contributors may 
-- *     be used to endorse or promote products derived from this software 
-- *     without specific prior written permission.
-- *
-- *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
-- *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
-- *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
-- *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
-- *  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
-- *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
-- *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
-- *  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
-- *  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
-- *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
-- *  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
-- *  SUCH DAMAGE.
-- *
-- ***************************************************************************
-- *  History:
-- *
-- *  02.08.2017  mifi  First version.
-- ***************************************************************************

-- ***************************************************************************
-- *  DEFINE: Library                                                        *
-- ***************************************************************************
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.NUMERIC_STD.ALL;


-- ***************************************************************************
-- *  DEFINE: Entity                                                         *
-- ***************************************************************************

entity uart_fifo_256_if is
   generic (
      FPGA_SYS_CLK_HZ : integer := 100000000;
      BAUDRATE        : integer := 115200
   );
	port (
		clk           : in  std_logic                     := '0';             --   clock.clk
		reset         : in  std_logic                     := '0';             --   reset.reset
      
		avs_address   : in  std_logic_vector(2 downto 0)  := (others => '0'); --      s0.address
		avs_read      : in  std_logic                     := '0';             --        .read
		avs_readdata  : out std_logic_vector(31 downto 0);                    --        .readdata
		avs_write     : in  std_logic                     := '0';             --        .write
		avs_writedata : in  std_logic_vector(31 downto 0) := (others => '0'); --        .writedata
      
      -- Conduit
      txd_o         : out std_logic;
      rxd_i         : in  std_logic
	);
end entity uart_fifo_256_if;

--***************************************************************************
--*  DEFINE: Architecture                                                   *
--***************************************************************************

architecture syn of uart_fifo_256_if is

   --------------------------------------------------------
   -- Define all constants here
   --------------------------------------------------------
   
   --------------------------------------------------------
   -- Define all components which are included here
   --------------------------------------------------------

   component uart_core is
      generic (
         FPGA_SYS_CLK_HZ : integer;
         BAUDRATE        : integer
      );
	   port (
         -- System
		   clk_i       : in  std_logic                    := '0';
		   rst_i       : in  std_logic                    := '0';
      
         -- Avalon
		   address_i   : in  std_logic_vector(2 downto 0) := (others => '0');
		   read_i      : in  std_logic                    := '0';
		   readdata_o  : out std_logic_vector(7 downto 0);
		   write_i     : in  std_logic                    := '0';
		   writedata_i : in  std_logic_vector(7 downto 0) := (others => '0');
         
         -- Conduit
         txd_o       : out std_logic;
         rxd_i       : in  std_logic
	   );
   end component uart_core;   
   
   --------------------------------------------------------
   -- Define all local signals here
   --------------------------------------------------------
   
   signal readdata : std_logic_vector(7 downto 0);
   
begin

   inst_uart : uart_core 
      generic map (
         FPGA_SYS_CLK_HZ => FPGA_SYS_CLK_HZ,
         BAUDRATE        => BAUDRATE
      )
      port map ( 
		   -- System 
         clk_i       => clk,
         rst_i       => reset,

			-- Avalon 
		   address_i   => avs_address,
		   read_i      => avs_read,
		   readdata_o  => readdata,
		   write_i     => avs_write,
		   writedata_i => avs_writedata(7 downto 0),
         
         -- Conduit
         txd_o       => txd_o,
         rxd_i       => rxd_i
      );
      
      avs_readdata <= x"000000" & readdata;

end architecture syn;

-- *** EOF ***
